﻿using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9649
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        bool isDrag = false;

        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.DecimalDegree;


            LayerOverlay layerOverlay = new LayerOverlay();
            ShapeFileFeatureLayer shapeFileLayer = new ShapeFileFeatureLayer(@"..\..\AppData\states.shp");
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = WorldStreetsAreaStyles.Military();
            shapeFileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            shapeFileLayer.Open();
            layerOverlay.Layers.Add(shapeFileLayer);
            map.Overlays.Add(layerOverlay);

            SimpleMarkerOverlay simpleMarkerOverlay = new SimpleMarkerOverlay();
            simpleMarkerOverlay.MarkerDragging += SimpleMarkerOverlay_MarkerDragging;
            simpleMarkerOverlay.MarkerDragged += SimpleMarkerOverlay_MarkerDragged;
            simpleMarkerOverlay.DragMode = MarkerDragMode.Drag;

            PointShape pointShape = shapeFileLayer.GetBoundingBox().GetCenterPoint();
            Marker marker = new Marker(pointShape.X, pointShape.Y);
            marker.MarkerMouseMove += Marker_MarkerMouseMove;


            //marker.MarkerMouseDown += Marker_MarkerMouseDown;
            //marker.MarkerMouseUp += Marker_MarkerMouseUp;

            marker.ImageSource = null;
            marker.Content = "Test Marker";
            marker.FontSize = 14;
            marker.FontStyle = FontStyles.Oblique;
            simpleMarkerOverlay.Markers.Add(marker);


            map.Overlays.Add(simpleMarkerOverlay);

            map.CurrentExtent = shapeFileLayer.GetBoundingBox();
            map.Refresh();
        }

        private void SimpleMarkerOverlay_MarkerDragged(object sender, MarkerDraggedSimpleMarkerOverlayEventArgs e)
        {
            isDrag = false;
        }

        private void SimpleMarkerOverlay_MarkerDragging(object sender, MarkerDraggingSimpleMarkerOverlayEventArgs e)
        {
            isDrag = true;
        }

        //private void Marker_MarkerMouseUp(object sender, System.Windows.Input.MouseButtonEventArgs e)
        //{
        //    isDrag = false;
        //}

        //private void Marker_MarkerMouseDown(object sender, System.Windows.Input.MouseButtonEventArgs e)
        //{
        //    isDrag = true;
        //}

        private void Marker_MarkerMouseMove(object sender, System.Windows.Input.MouseEventArgs e)
        {
            if (isDrag)
            {
                Point point = e.MouseDevice.GetPosition(null);
                ScreenPointF screenPointF = new ScreenPointF((float)point.X, (float)point.Y);
                PointShape pointShape = ExtentHelper.ToWorldCoordinate(map.CurrentExtent, screenPointF, (float)map.ActualWidth, (float)map.ActualHeight);

                X.Text = "X: " + pointShape.X.ToString();
                Y.Text = "Y: " + pointShape.Y.ToString();
            }
        }
    }
}
